@@ -64,6 +64,8 @@ void KatePluginManager::setupPluginList ()
 {
   KService::List traderList = KServiceTypeTrader::self()->query("Kate/Plugin", "(not ('Kate/ProjectPlugin' in ServiceTypes)) and (not ('Kate/InitPlugin' in ServiceTypes))");
 
+  KatePluginList alwaysLoad;
+  KatePluginList others;
   foreach(const KService::Ptr &ptr, traderList)
   {
     double pVersion = ptr->property("X-Kate-Version").toDouble();
@@ -72,14 +74,23 @@ void KatePluginManager::setupPluginList ()
     if ((pVersion >= 2.8) && (pVersion <= KateApp::kateVersion(false).toDouble()))
     {
       KatePluginInfo info;
-
-      info.load = false;
       info.service = ptr;
+      info.alwaysLoad=info.service->property("X-Kate-LoadAlways").toBool();
+      info.load = false;
       info.plugin = 0L;
-
-      m_pluginList.push_back (info);
+      
+      if (info.alwaysLoad)
+        alwaysLoad.push_back (info);
+      else
+        others.push_back (info);
     }
   }
+  
+  /**
+   * prefer always load plugins in handling
+   */
+  m_pluginList = alwaysLoad;
+  m_pluginList << others;
 }
 
 void KatePluginManager::loadConfig (KConfig* config)
@@ -87,15 +98,27 @@ void KatePluginManager::loadConfig (KConfig* config)
   // first: unload the plugins
   unloadAllPlugins ();
 
-  if ( ! config ) return;
-
-  KConfigGroup cg = KConfigGroup(config, "Kate Plugins");
-
-  // disable all plugin if no config...
-  foreach (const KatePluginInfo &plugin, m_pluginList)
-    plugin.load =  cg.readEntry (plugin.service->library(), false) ||
-                 cg.readEntry (plugin.service->property("X-Kate-PluginName").toString(), false);
+  /**
+   * ask config object
+   */
+  if (config) {
+    KConfigGroup cg = KConfigGroup(config, "Kate Plugins");
 
+    // disable all plugin if no config...
+    foreach (const KatePluginInfo &plugin, m_pluginList) {
+      plugin.load = cg.readEntry (plugin.service->library(), false) ||
+                  cg.readEntry (plugin.service->property("X-Kate-PluginName").toString(), false);
+    }
+  }
+  
+  /**
+   * some plugins should be always loaded, like the holy filetree
+   */
+  foreach (const KatePluginInfo &plugin, m_pluginList) {
+    if (plugin.service->property("X-Kate-LoadAlways").toBool())
+      plugin.load = true;    
+  }
+  
   for (KatePluginList::iterator it = m_pluginList.begin();it != m_pluginList.end(); ++it)
   {
     if (it->load)
