@@ -96,6 +96,10 @@ KateSession::~KateSession ()
 
 QString KateSession::sessionFile () const
 {
+  if (m_sessionFileRel.isEmpty()) {
+    return QString();
+  }
+
   return m_manager->sessionsDir() + '/' + m_sessionFileRel;
 }
 
@@ -165,7 +169,7 @@ bool KateSession::rename (const QString &name)
 KConfig *KateSession::configRead ()
 {
   if (m_sessionFileRel.isEmpty())
-    return 0;
+    return KGlobal::config().data();
 
   if (m_readConfig)
     return m_readConfig;
@@ -176,7 +180,7 @@ KConfig *KateSession::configRead ()
 KConfig *KateSession::configWrite ()
 {
   if (m_sessionFileRel.isEmpty())
-    return 0;
+    return KGlobal::config().data();
 
   if (m_writeConfig)
     return m_writeConfig;
@@ -208,7 +212,6 @@ KateSessionManager::KateSessionManager (QObject *parent)
     : QObject (parent)
     , m_sessionsDir (KStandardDirs::locateLocal( "data", "kate/sessions"))
     , m_activeSession (new KateSession (this, QString()))
-    , m_defaultSessionFile(KStandardDirs::locate( "data", "kate/default.katesession"))
 {
   kDebug() << "LOCAL SESSION DIR: " << m_sessionsDir;
 
@@ -224,11 +227,6 @@ KateSessionManager *KateSessionManager::self()
   return KateApp::self()->sessionManager ();
 }
 
-QString KateSessionManager::defaultSessionFile() const
-{
-  return m_defaultSessionFile;
-}
-
 void KateSessionManager::dirty (const QString &)
 {
   updateSessionList ();
@@ -310,13 +308,12 @@ bool KateSessionManager::activateSession (KateSession::Ptr session,
   {
     // open the new session
     KConfig *sc = activeSession()->configRead();
-    const bool loadDocs = (sc != 0); // do not load docs for new sessions
+    const bool loadDocs = (sc != KGlobal::config().data()); // do not load docs for new sessions
 
     // if we have no session config object, try to load the default
     // (anonymous/unnamed sessions)
     if ( !sc )
-      sc = new KConfig( defaultSessionFile(), KConfig::SimpleConfig );
-
+      sc = KGlobal::config().data();
     // load plugin config + plugins
     KatePluginManager::self()->loadConfig (sc);
 
@@ -330,7 +327,7 @@ bool KateSessionManager::activateSession (KateSession::Ptr session,
     {
       // a new, named session, read settings of the default session.
       if ( ! sc->hasGroup("Open MainWindows") )
-        sc = new KConfig( defaultSessionFile(), KConfig::SimpleConfig );
+        sc = KGlobal::config().data();
 
       int wCount = sc->group("Open MainWindows").readEntry("Count", 1);
 
@@ -432,20 +429,9 @@ bool KateSessionManager::chooseSession ()
   KConfigGroup c(KGlobal::config(), "General");
 
   // get last used session, default to default session
-  QString lastSession (c.readEntry ("Last Session", defaultSessionFile()));
+  QString lastSession (c.readEntry ("Last Session", QString()));
   QString sesStart (c.readEntry ("Startup Session", "manual"));
 
-  // if this is the first time Kate App starts, create a i18ned default.katesession
-  bool firstStart = c.readEntry ("First Start", true);
-  if (firstStart) {
-    c.writeEntry ("First Start", false);
-    QFile::copy(defaultSessionFile(), sessionsDir() + "/default.katesession");
-    KateSession *ds = new KateSession(this, "default.katesession");
-    ds->rename(i18n("Default Session"));
-    lastSession=ds->sessionFileRelative();
-    delete ds;
-  }
-
   // uhh, just open last used session, show no chooser
   if (sesStart == "last")
   {
@@ -604,23 +590,6 @@ bool KateSessionManager::newSessionName()
   return true;
 }
 
-void KateSessionManager::sessionSaveAsDefault ()
-{
-  // get path of local default.katesession file
-  QString localSessionFile = KStandardDirs::locateLocal("data", "kate/default.katesession");
-
-  // use this local file to store the defaults to
-  KConfig defaultConfig(localSessionFile, KConfig::SimpleConfig);
-//  defaultConfig.group("General").writeEntry ("Name", QString());
-
-  saveSessionTo(&defaultConfig);
-
-  // in case the local default.katesession did not exist, the KateSessionManager
-  // constructor set the default.katesession to the global KDE directory. But
-  // now we are sure the local file exists, so point to if from now on...
-  m_defaultSessionFile = localSessionFile;
-}
-
 void KateSessionManager::sessionManage ()
 {
   KateSessionManageDialog *dlg = new KateSessionManageDialog (0);
@@ -805,7 +774,7 @@ KateSessionOpenDialog::KateSessionOpenDialog (QWidget *parent)
   setResult (resultCancel);
   connect(this, SIGNAL(user1Clicked()), this, SLOT(slotUser1()));
   connect(this, SIGNAL(user2Clicked()), this, SLOT(slotUser2()));
-  connect(m_sessions, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(selectionChanged()));
+  connect(m_sessions, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(selectionChanged(QTreeWidgetItem *, QTreeWidgetItem *)));
   connect(m_sessions, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotUser2()));
 
 }
@@ -987,7 +956,12 @@ KateSessionsAction::KateSessionsAction(const QString& text, QObject* parent)
   connect(menu(), SIGNAL(aboutToShow()), this, SLOT(slotAboutToShow()));
 
   sessionsGroup = new QActionGroup( menu() );
-  connect(sessionsGroup, SIGNAL( triggered(QAction *) ), this, SLOT( openSession(QAction *)));
+
+  // reason for Qt::QueuedConnection: when switching session with N mainwindows
+  // to e.g. 1 mainwindow, the last N - 1 mainwindows are deleted. Invoking
+  // a session switch without queued connection deletes a mainwindow in which
+  // the current code path is executed ---> crash. See bug #227008.
+  connect(sessionsGroup, SIGNAL( triggered(QAction *) ), this, SLOT( openSession(QAction *)), Qt::QueuedConnection);
 }
 
 void KateSessionsAction::slotAboutToShow()
@@ -997,7 +971,9 @@ void KateSessionsAction::slotAboutToShow()
   const KateSessionList &slist (KateSessionManager::self()->sessionList());
   for (int i = 0; i < slist.count(); ++i)
   {
-    QAction *action = new QAction( slist[i]->sessionName(), sessionsGroup );
+    QString sessionName = slist[i]->sessionName();
+    sessionName.replace("&", "&&");
+    QAction *action = new QAction( sessionName, sessionsGroup ); 
     action->setData(QVariant(i));
     menu()->addAction (action);
   }
