@@ -647,8 +647,8 @@ void KateViewManager::removeViewSpace (KateViewSpace *viewspace)
       // save current splitter size, as the removal of currentSplitter looses the info
       QList<int> parentSizes = parentSplitter->sizes();
       parentSplitter->insertWidget (index, currentSplitter->widget (0));
-      currentSplitter->hide();
-      delete currentSplitter; // do not delete imidiatelly
+      if (qVersion() == QLatin1String("4.6.2")) currentSplitter->hide(); // bug in Qt v4.6.2, prevents crash (bug:232140), line can be removed once we are sure that noone uses Qt 4.6.2 anymore.
+      delete currentSplitter;
       // now restore the sizes again
       parentSplitter->setSizes(parentSizes);
     }
