@@ -2,7 +2,7 @@
                                 komparelistview.h
                                 -----------------
         begin                   : Sun Mar 4 2001
-        Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2004,2009 Otto Bruggeman <bruggie@gmail.com>
         Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
         Copyright 2004      Jeff Snyder    <jeff@caffeinated.me.uk>
 ****************************************************************************/
@@ -19,16 +19,13 @@
 #ifndef KOMPARELISTVIEW_H
 #define KOMPARELISTVIEW_H
 
-#include <Q3PtrList>
-#include <Q3ValueList>
-#include <Q3PtrDict>
+#include <QHash>
 #include <QLabel>
-#include <QLayout>
 #include <QResizeEvent>
 #include <QWheelEvent>
-#include <Q3VBoxLayout>
+#include <QVBoxLayout>
 #include <QMouseEvent>
-#include <Q3Frame>
+#include <QFrame>
 
 #include <k3listview.h>
 
@@ -37,7 +34,6 @@ class DiffModel;
 class DiffHunk;
 class Difference;
 class DifferenceString;
-class KompareModelList;
 }
 class ViewSettings;
 class KompareSplitter;
@@ -67,9 +63,6 @@ public:
 
 	void setSelectedDifference( const Diff2::Difference* diff, bool scroll );
 
-	const QString& spaces() const { return m_spaces; };
-	void setSpaces( int spaces );
-
 public slots:
 	void slotSetSelection( const Diff2::DiffModel* model, const Diff2::Difference* diff );
 	void slotSetSelection( const Diff2::Difference* diff );
@@ -92,23 +85,23 @@ protected:
 	void contentsMouseDoubleClickEvent ( QMouseEvent* );
 	void contentsMouseReleaseEvent ( QMouseEvent * ) {};
 	void contentsMouseMoveEvent ( QMouseEvent * ) {};
+	void renumberLines( void );
 
 private:
-	Q3ValueList<KompareListViewDiffItem*> m_items;
-	Q3PtrDict<KompareListViewDiffItem> m_itemDict;
+	QList<KompareListViewDiffItem*> m_items;
+	QHash<const Diff2::Difference*, KompareListViewDiffItem*> m_itemDict;
 	bool                              m_isSource;
 	ViewSettings*                     m_settings;
 	int                               m_scrollId;
 	int                               m_maxMainWidth;
 	const Diff2::DiffModel*           m_selectedModel;
 	const Diff2::Difference*          m_selectedDifference;
-	QString                           m_spaces;
 };
 
-class KompareListViewFrame : public Q3Frame
+class KompareListViewFrame : public QFrame
 {
 	Q_OBJECT
-	
+
 public:
 	KompareListViewFrame( bool isSource, ViewSettings* settings, KompareSplitter* parent, const char* name = 0 );
 	virtual ~KompareListViewFrame() {};
@@ -120,9 +113,10 @@ public slots:
 private:
 	KompareListView      m_view;
 	QLabel               m_label;
-	Q3VBoxLayout          m_layout;
+	QVBoxLayout          m_layout;
 };
 
+
 class KompareListViewItem : public Q3ListViewItem
 {
 public:
@@ -135,9 +129,12 @@ public:
 	int scrollId() { return m_scrollId; };
 
 	virtual int maxHeight() = 0;
+	virtual int rtti(void) const = 0;
 
 	KompareListView* kompareListView() const;
 
+	enum ListViewItemType { Diff = 1001, Container = 1002, Line = 1003, Blank = 1004, Hunk = 1005 };
+
 private:
 	int     m_scrollId;
 };
@@ -147,6 +144,7 @@ class KompareListViewDiffItem : public KompareListViewItem
 public:
 	KompareListViewDiffItem( KompareListView* parent, Diff2::Difference* difference );
 	KompareListViewDiffItem( KompareListView* parent, KompareListViewItem* after, Diff2::Difference* difference );
+	~KompareListViewDiffItem();
 
 	void setup();
 	void setSelected( bool b );
@@ -154,24 +152,31 @@ public:
 
 	Diff2::Difference* difference() { return m_difference; };
 
-	int maxHeight();
+	virtual int maxHeight();
+	virtual int rtti(void) const { return Diff; };
 
 private:
 	void init();
 	void setVisibility();
 
+private:
 	Diff2::Difference* m_difference;
 	KompareListViewLineContainerItem* m_sourceItem;
 	KompareListViewLineContainerItem* m_destItem;
 };
 
+class KompareListViewLineItem;
+class KompareListViewBlankLineItem;
+
 class KompareListViewLineContainerItem : public KompareListViewItem
 {
 public:
 	KompareListViewLineContainerItem( KompareListViewDiffItem* parent, bool isSource );
+	~KompareListViewLineContainerItem();
 
 	void setup();
-	int maxHeight() { return 0; }
+	virtual int maxHeight() { return 0; }
+	virtual int rtti(void) const { return Container; };
 	KompareListViewDiffItem* diffItemParent() const;
 
 private:
@@ -179,6 +184,9 @@ private:
 	int lineNumber() const;
 	Diff2::DifferenceString* lineAt( int i ) const;
 
+private:
+	QList<KompareListViewLineItem *> m_lineItemList;
+	KompareListViewBlankLineItem* m_blankLineItem;
 	bool m_isSource;
 };
 
@@ -186,15 +194,20 @@ class KompareListViewLineItem : public KompareListViewItem
 {
 public:
 	KompareListViewLineItem( KompareListViewLineContainerItem* parent, int line, Diff2::DifferenceString* text );
+	~KompareListViewLineItem();
 
 	virtual void setup();
-	int maxHeight() { return 0; }
+	virtual int maxHeight() { return 0; }
+	virtual int rtti(void) const { return Line; };
 
 	virtual void paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int align );
 	virtual void paintText( QPainter* p, const QColor& bg, int column, int width, int align );
 
 	KompareListViewDiffItem* diffItemParent() const;
 
+private:
+	void expandTabs(QString& text, int tabstop, int startPos = 0) const;
+
 private:
 	Diff2::DifferenceString* m_text;
 };
@@ -205,6 +218,7 @@ public:
 	KompareListViewBlankLineItem( KompareListViewLineContainerItem* parent );
 
 	void setup();
+	virtual int rtti(void) const { return Blank; };
 
 	void paintText( QPainter* p, const QColor& bg, int column, int width, int align );
 };
@@ -214,11 +228,13 @@ class KompareListViewHunkItem : public KompareListViewItem
 public:
 	KompareListViewHunkItem( KompareListView* parent, Diff2::DiffHunk* hunk, bool zeroHeight = false );
 	KompareListViewHunkItem( KompareListView* parent, KompareListViewItem* after, Diff2::DiffHunk* hunk, bool zeroHeight= false );
+	~KompareListViewHunkItem();
 
 	void setup();
 	void paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int align );
 
-	int maxHeight();
+	virtual int maxHeight();
+	virtual int rtti(void) const { return Hunk; };
 
 private:
 	bool             m_zeroHeight;
