@@ -76,11 +76,6 @@ const QString& CatalogItem::msgid(const int form) const
     return d->msgid(form);
 }
 
-const QVector<QString>& CatalogItem::msgidPlural(const bool /*noNewlines*/) const
-{
-    return d->_msgidPlural;
-}
-
 const QString& CatalogItem::msgstr(const int form) const
 {
     if (KDE_ISLIKELY (form<d->_msgstrPlural.size()))
@@ -89,11 +84,22 @@ const QString& CatalogItem::msgstr(const int form) const
         return d->_msgstrPlural.last();
 }
 
-const QVector<QString>& CatalogItem::msgstrPlural(const bool /*noNewlines*/) const
+const QVector<QString>& CatalogItem::msgstrPlural() const
 {
     return d->_msgstrPlural;
 }
 
+QStringList CatalogItem::allPluralForms(CatalogItem::Part part, bool stripNewLines) const
+{
+    QStringList result=(part==CatalogItem::Source?d->_msgidPlural:d->_msgstrPlural).toList();
+    if (stripNewLines)
+    {
+        static QString nl="\n";
+        result.replaceInStrings(nl, QString());
+    }
+    return result;
+}
+
 bool CatalogItem::isValid() const
 {
     return d->_valid;
@@ -112,10 +118,9 @@ void CatalogItem::setMsgctxt(const QString& msg)
 
 void CatalogItem::setMsgid(const QString& msg, const int form)
 {
-    if (form<d->_msgidPlural.size())
-        d->_msgidPlural[form]=msg;
-    else
-        d->_msgidPlural.append(msg);
+    if (form>=d->_msgidPlural.size())
+        d->_msgidPlural.resize(form+1);
+    d->_msgidPlural[form]=msg;
 }
 
 void CatalogItem::setMsgid(const QStringList& msg)
@@ -134,10 +139,9 @@ void CatalogItem::setMsgid(const QVector<QString>& msg)
 
 void CatalogItem::setMsgstr(const QString& msg, const int form)
 {
-    if (form<d->_msgstrPlural.size())
-        d->_msgstrPlural[form]=msg;
-    else
-        d->_msgstrPlural.append(msg);
+    if (form>=d->_msgstrPlural.size())
+        d->_msgstrPlural.resize(form+1);
+    d->_msgstrPlural[form]=msg;
 }
 
 void CatalogItem::setMsgstr(const QStringList& msg)
@@ -155,6 +159,7 @@ void CatalogItem::setComment(const QString& com)
 {
     d->_comment=com;
     d->_comment.squeeze();
+    d->_fuzzyCached=com.contains( QRegExp(fuzzyRegExpStr) );
 }
 
 void CatalogItem::setPlural(bool plural)
@@ -169,7 +174,7 @@ bool CatalogItem::isPlural() const
 
 bool CatalogItem::isFuzzy() const
 {
-    return d->_comment.contains( QRegExp(fuzzyRegExpStr) );
+    return d->_fuzzyCached;
 }
 
 bool CatalogItem::isUntranslated() const
@@ -295,6 +300,8 @@ QStringList CatalogItem::msgstrAsList() const
 
 void CatalogItem::setFuzzy()
 {
+    d->_fuzzyCached=true;
+
     QString& comment=d->_comment;
     if (comment.isEmpty())
     {
@@ -326,9 +333,13 @@ void CatalogItem::setFuzzy()
 
 void CatalogItem::unsetFuzzy()
 {
-    QString& comment=d->_comment;
+    d->_fuzzyCached=false;
 
-    comment.remove( QRegExp(fuzzyRegExpStr) );
+    QString& comment=d->_comment;
+    //kDebug()<<comment;
+
+    static const QRegExp rmFuzzyRe(",\\s*fuzzy");
+    comment.remove( rmFuzzyRe );
 
     // remove empty comment lines
     comment.remove( QRegExp("\n#\\s*$") );
@@ -336,6 +347,7 @@ void CatalogItem::unsetFuzzy()
     comment.remove( QRegExp("#\\s*\n") );
     comment.remove( QRegExp("^#\\s*\n") );
 
+    //kDebug()<<comment;
 }
 
 
