@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -33,10 +33,20 @@
 #include <QFile>
 #include <QXmlSimpleReader>
 #include <QXmlStreamReader>
+#include <QBuffer>
+#include <QApplication>
 
 using namespace GlossaryNS;
 
 static const QString defaultLang="en_US";
+static const QString xmlLang="xml:lang";
+static const QString ntig="ntig";
+static const QString termGrp="termGrp";
+static const QString langSet="langSet";
+static const QString term="term";
+static const QString id="id";
+
+
 
 QStringList Glossary::idsForLangWord(const QString& lang, const QString& word) const
 {
@@ -45,15 +55,33 @@ QStringList Glossary::idsForLangWord(const QString& lang, const QString& word) c
 }
 
 
-//BEGIN DISK
-void Glossary::load(const QString& newPath)
+Glossary::Glossary(QObject* parent)
+ : QObject(parent)
 {
+}
+
+
+//BEGIN DISK
+bool Glossary::load(const QString& newPath)
+{
+    QTime a;a.start();
 //BEGIN NEW
-    QFile* device=new QFile(newPath);
+    QIODevice* device=new QFile(newPath);
     if (!device->open(QFile::ReadOnly | QFile::Text))
     {
         delete device;
-        return;
+        //return;
+        device=new QBuffer();
+        static_cast<QBuffer*>(device)->setData(QByteArray(
+"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+"<!DOCTYPE martif PUBLIC \"ISO 12200:1999A//DTD MARTIF core (DXFcdV04)//EN\" \"TBXcdv04.dtd\">\n"
+"<martif type=\"TBX\" xml:lang=\"en_US\">\n"
+"    <text>\n"
+"        <body>\n"
+"        </body>\n"
+"    </text>\n"
+"</martif>\n"
+));
     }
 
     QXmlSimpleReader reader;
@@ -71,29 +99,18 @@ void Glossary::load(const QString& newPath)
     if (!success)
     {
         kWarning()<<errorMsg;
-        return; //errorLine+1;
+        return false; //errorLine+1;
     }
-    clear();//does setClean(true);;
+    clear();//does setClean(true);
     m_path=newPath;
     m_doc=newDoc;
 
-
-//BEGIN compat code
-    QDomNodeList langSets=m_doc.elementsByTagName("langSet");
-    for(int i=0;i<langSets.size();i++)
-    {
-        QDomElement langSet=langSets.at(i).toElement();
-        if (langSet.attribute("xml:lang")=="en")
-            langSet.setAttribute("xml:lang", defaultLang);
-    }
-//END compat code
-
     //QDomElement file=m_doc.elementsByTagName("file").at(0).toElement();
     m_entries=m_doc.elementsByTagName("termEntry");
     for(int i=0;i<m_entries.size();i++)
         hashTermEntry(m_entries.at(i).toElement());
+    m_idsForEntriesById=m_entriesById.keys();
 
-    
 //END NEW
 #if 0
     TbxParser parser(this);
@@ -107,16 +124,20 @@ void Glossary::load(const QString& newPath)
     if (!reader1.parse(xmlInputSource))
          kWarning() << "failed to load "<< path;
 #endif
-    emit changed();
+    emit loaded();
+    return true;
 }
 
-void Glossary::save()
+bool Glossary::save()
 {
+    if (m_path.isEmpty())
+        return false;
+    
     QFile* device=new QFile(m_path);
     if (!device->open(QFile::WriteOnly | QFile::Truncate))
     {
         device->deleteLater();
-        return;
+        return false;
     }
     QTextStream stream(device);
     m_doc.save(stream,2);
@@ -124,6 +145,7 @@ void Glossary::save()
     device->deleteLater();
 
     setClean(true);
+    return true;
 }
 
 void Glossary::setClean(bool clean)
@@ -135,12 +157,63 @@ void Glossary::setClean(bool clean)
 //END DISK
 
 //BEGIN MODEL
+#define FETCH_SIZE 128
+
+void GlossarySortFilterProxyModel::setFilterRegExp(const QString& s)
+{
+    if (!sourceModel())
+      return;
+
+    //static const QRegExp lettersOnly("^[a-z]");
+    QSortFilterProxyModel::setFilterRegExp(s);
+
+    fetchMore(QModelIndex());
+}
+
+void GlossarySortFilterProxyModel::fetchMore(const QModelIndex& parent)
+{
+    int expectedCount=rowCount()+FETCH_SIZE/2;
+    while (rowCount(QModelIndex())<expectedCount && sourceModel()->canFetchMore(QModelIndex()))
+    {
+        sourceModel()->fetchMore(QModelIndex());
+        //qDebug()<<"filter:"<<rowCount(QModelIndex())<<"/"<<sourceModel()->rowCount();
+        qApp->processEvents();
+    }
+}
+
+GlossaryModel::GlossaryModel(QObject* parent)
+ : QAbstractListModel(parent)
+ , m_visibleCount(0)
+ , m_glossary(Project::instance()->glossary())
+{
+    connect(m_glossary, SIGNAL(loaded()), this, SLOT(forceReset()));
+}
+
+void GlossaryModel::forceReset()
+{
+    beginResetModel();
+    m_visibleCount=0;
+    endResetModel();
+}
+
+bool GlossaryModel::canFetchMore(const QModelIndex& parent) const
+{
+    return false;//!parent.isValid() && m_glossary->size()!=m_visibleCount;
+}
+
+void GlossaryModel::fetchMore(const QModelIndex& parent)
+{
+    int newVisibleCount=qMin(m_visibleCount+FETCH_SIZE,m_glossary->size());
+    beginInsertRows(parent, m_visibleCount, newVisibleCount-1);
+    m_visibleCount=newVisibleCount;
+    endInsertRows();
+}
 
 int GlossaryModel::rowCount(const QModelIndex& parent) const
 {
     if (parent.isValid())
         return 0;
-    return Project::instance()->glossary()->size();
+    return m_glossary->size();//m_visibleCount;
 }
 
 QVariant GlossaryModel::headerData( int section, Qt::Orientation /*orientation*/, int role) const
@@ -150,7 +223,7 @@ QVariant GlossaryModel::headerData( int section, Qt::Orientation /*orientation*/
 
     switch (section)
     {
-//         case ID: return i18nc("@title:column","ID");
+        //case ID: return i18nc("@title:column","ID");
         case English: return i18nc("@title:column Original text","Source");;
         case Target: return i18nc("@title:column Text in target language","Target");
         case SubjectField: return i18nc("@title:column","Subject Field");
@@ -160,12 +233,15 @@ QVariant GlossaryModel::headerData( int section, Qt::Orientation /*orientation*/
 
 QVariant GlossaryModel::data(const QModelIndex& index, int role) const
 {
+    //if (role==Qt::SizeHintRole)
+    //    return QVariant(QSize(50, 30));
+
     if (role!=Qt::DisplayRole)
         return QVariant();
 
-    static const QString nl="\n";
-    Project* project=Project::instance();
-    Glossary* glossary=project->glossary();
+    static const QString nl=QString(" ")+QChar(0x00B7)+' ';
+    static Project* project=Project::instance();
+    Glossary* glossary=m_glossary;
 
     QString id=glossary->id(index.row());
     switch (index.column())
@@ -190,12 +266,15 @@ int GlossaryModel::columnCount(const QModelIndex&) const
     return GlossaryModelColumnCount;
 }
 
+/*
 Qt::ItemFlags GlossaryModel::flags ( const QModelIndex & index ) const
 {
-/*    if (index.column()==FuzzyFlag)
-        return Qt::ItemIsSelectable|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled;*/
-    return QAbstractItemModel::flags(index);
+    return Qt::ItemIsSelectable|Qt::ItemIsEnabled;
+    //if (index.column()==FuzzyFlag)
+    //    return Qt::ItemIsSelectable|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled;
+    //return QAbstractItemModel::flags(index);
 }
+*/
 
 
 //END MODEL general (GlossaryModel continues below)
@@ -213,7 +292,7 @@ QString Glossary::generateNewId()
     QRegExp rx('^'+authorId+"\\-([0-9]*)$");
 
 
-    foreach(const QString& id, m_entriesById.keys())
+    foreach(const QString& id, m_idsForEntriesById)
     {
         if (rx.exactMatch(id))
             busyIdNumbers.append(rx.cap(1).toInt());
@@ -239,32 +318,32 @@ QString Glossary::generateNewId()
 QStringList Glossary::subjectFields() const
 {
     QSet<QString> result;
-    foreach(const QString& id, m_entriesById.keys())
+    foreach(const QString& id, m_idsForEntriesById)
         result.insert(subjectField(id));
     return result.toList();
 }
 
 QString Glossary::id(int index) const
 {
-    const QList<QString>& keys=m_entriesById.keys();
-    if (index<keys.size())
-        return m_entriesById.keys().at(index);
+    if (index<m_idsForEntriesById.size())
+        return m_idsForEntriesById.at(index);
     return QString();
 }
 
 QStringList Glossary::terms(const QString& id, const QString& language) const
 {
     QStringList result;
-    QDomElement n = m_entriesById.value(id).firstChildElement("langSet");
+    QDomElement n = m_entriesById.value(id).firstChildElement(langSet);
     while (!n.isNull())
     {
-        QString lang=n.attribute("xml:lang", "en");
+        QString lang=n.attribute(xmlLang, defaultLang);
+        if (lang=="en") //NOTE COMPAT
+            lang=defaultLang;
+
         if (language==lang)
-        {
-            QString term=n.firstChildElement("ntig").firstChildElement("termGrp").firstChildElement("term").text();
-            result<<term;
-        }
-        n = n.nextSiblingElement("langSet");
+            result<<n.firstChildElement(ntig).firstChildElement(termGrp).firstChildElement(term).text();
+
+        n = n.nextSiblingElement(langSet);
     }
 
     return result;
@@ -287,35 +366,41 @@ static void setText(QDomElement element, QString text)
         element.appendChild( element.ownerDocument().createTextNode(text));
 }
 
-void Glossary::setTerm(const QString& id, const QString& lang, int index, const QString& termText)
+void Glossary::setTerm(const QString& id, QString lang, int index, const QString& termText)
 {
     setClean(false);
 
-    QDomElement n = m_entriesById.value(id).firstChildElement("langSet");
+    QDomElement n = m_entriesById.value(id).firstChildElement(langSet);
     QDomDocument document=n.ownerDocument();
     int i=0;
     while (!n.isNull())
     {
-        QString nLang=n.attribute("xml:lang", "en");
+        QString nLang=n.attribute(xmlLang, defaultLang);
+        if (lang=="en") //NOTE COMPAT
+        {
+            lang=defaultLang;
+            n.setAttribute(xmlLang, defaultLang);
+        }
+
         if (lang==nLang)
         {
             if (i==index)
             {
-                QDomElement term=n.firstChildElement("ntig").firstChildElement("termGrp").firstChildElement("term");
-                setText(term,termText);
+                QDomElement termElement=n.firstChildElement(ntig).firstChildElement(termGrp).firstChildElement(term);
+                setText(termElement,termText);
                 return;
             }
             i++;
         }
-        n = n.nextSiblingElement("langSet");
+        n = n.nextSiblingElement(langSet);
     }
     n = m_entriesById.value(id).toElement();
-    QDomElement langSet=n.appendChild( document.createElement("langSet")).toElement();
-    langSet.setAttribute("xml:lang",lang);
-    QDomElement ntig=langSet.appendChild( document.createElement("ntig")).toElement();
-    QDomElement termGrp=ntig.appendChild( document.createElement("termGrp")).toElement();
-    QDomElement term=termGrp.appendChild( document.createElement("term")).toElement();
-    term.appendChild( document.createTextNode(termText));
+    QDomElement langSetElement=n.appendChild( document.createElement(langSet)).toElement();
+    langSetElement.setAttribute(xmlLang,lang);
+    QDomElement ntigElement=langSetElement.appendChild( document.createElement(ntig)).toElement();
+    QDomElement termGrpElement=ntigElement.appendChild( document.createElement(termGrp)).toElement();
+    QDomElement termElement=termGrpElement.appendChild( document.createElement(term)).toElement();
+    termElement.appendChild( document.createTextNode(termText));
 }
 
 
@@ -378,13 +463,16 @@ QStringList Glossary::terms(int index, const QString& language) const
 {
     QStringList result;
     Q_ASSERT(index<m_entries.size());
-    QDomElement n = m_entries.at(index).firstChildElement("langSet");
+    QDomElement n = m_entries.at(index).firstChildElement(langSet);
     while (!n.isNull())
     {
-        QString lang=n.attribute("xml:lang", "en");
+        QString lang=n.attribute(xmlLang, defaultLang);
+        if (lang=="en") //NOTE COMPAT
+            lang=defaultLang;
+
         if (language==lang)
-            result<<n.firstChildElement("ntig").firstChildElement("termGrp").firstChildElement("term").text();
-        n = n.nextSiblingElement("langSet");
+            result<<n.firstChildElement(ntig).firstChildElement(termGrp).firstChildElement(term).text();
+        n = n.nextSiblingElement(langSet);
     }
 
     return result;
@@ -397,33 +485,46 @@ QStringList Glossary::terms(int index, const QString& language) const
 //                       int index)
 void Glossary::hashTermEntry(const QDomElement& termEntry)
 {
-    m_entriesById.insert(termEntry.attribute("id"),termEntry);
+    QString entryId=termEntry.attribute(::id);
+    if (entryId.isEmpty())
+        return;
 
-    QDomElement n = termEntry.firstChildElement("langSet");
+    m_entriesById.insert(entryId,termEntry);
+
+    QDomElement n = termEntry.firstChildElement(langSet);
     while (!n.isNull())
     {
-        QString lang=n.attribute("xml:lang", defaultLang);
-        QString term=n.firstChildElement("ntig").firstChildElement("termGrp").firstChildElement("term").text();
-        foreach(const QString& word, term.split(' ',QString::SkipEmptyParts))
-            idsByLangWord[lang].insert(stem(lang,word),termEntry.attribute("id"));
+        QString lang=n.attribute(xmlLang, defaultLang);
+        if (lang=="en") //NOTE COMPAT
+        {
+            lang=defaultLang;
+            //n.setAttribute(xmlLang, defaultLang); freezes lokalize on large TBX
+        }
 
-        n = n.nextSiblingElement("langSet");
+        QString termText=n.firstChildElement(ntig).firstChildElement(termGrp).firstChildElement(term).text();
+        foreach(const QString& word, termText.split(' ',QString::SkipEmptyParts))
+            idsByLangWord[lang].insert(stem(lang,word),entryId);
+
+        n = n.nextSiblingElement(langSet);
     }
 }
 
 void Glossary::unhashTermEntry(const QDomElement& termEntry)
 {
-    m_entriesById.remove(termEntry.attribute("id"));
+    m_entriesById.remove(termEntry.attribute(::id));
 
-    QDomElement n = termEntry.firstChildElement("langSet");
+    QDomElement n = termEntry.firstChildElement(langSet);
     while (!n.isNull())
     {
-        QString lang=n.attribute("xml:lang", defaultLang);
-        QString term=n.firstChildElement("ntig").firstChildElement("termGrp").firstChildElement("term").text();
-        foreach(const QString& word, term.split(' ',QString::SkipEmptyParts))
-            idsByLangWord[lang].remove(stem(lang,word),termEntry.attribute("id"));
+        QString lang=n.attribute(xmlLang, defaultLang);
+        if (lang=="en") //NOTE COMPAT
+            lang=defaultLang;
 
-        n = n.nextSiblingElement("langSet");
+        QString termText=n.firstChildElement(ntig).firstChildElement(termGrp).firstChildElement(term).text();
+        foreach(const QString& word, termText.split(' ',QString::SkipEmptyParts))
+            idsByLangWord[lang].remove(stem(lang,word),termEntry.attribute(::id));
+
+        n = n.nextSiblingElement(langSet);
     }
 }
 
@@ -461,6 +562,7 @@ void Glossary::remove(const QString& id)
     m_entriesById.remove(id);
 
     unhashTermEntry(entry);
+    m_idsForEntriesById=m_entriesById.keys();
     removedIds.append(id); //for new id generation goodness
 
     setClean(false);
@@ -470,12 +572,12 @@ static void appendTerm(QDomElement entry, const QString& termText, const QString
 {
     QDomDocument doc=entry.ownerDocument();
 
-    QDomElement source=doc.createElement("langSet"); entry.appendChild(source);
-    source.setAttribute("xml:lang", lang);
-    QDomElement ntig=doc.createElement("ntig"); source.appendChild(ntig);
-    QDomElement termGrp=doc.createElement("termGrp"); ntig.appendChild(termGrp);
-    QDomElement term=doc.createElement("term"); termGrp.appendChild(term);
-    term.appendChild(doc.createTextNode(termText));
+    QDomElement source=doc.createElement(langSet); entry.appendChild(source);
+    source.setAttribute(xmlLang, lang);
+    QDomElement ntigElement=doc.createElement(ntig); source.appendChild(ntigElement);
+    QDomElement termGrpElement=doc.createElement(termGrp); ntigElement.appendChild(termGrpElement);
+    QDomElement termElement=doc.createElement(term); termGrpElement.appendChild(termElement);
+    termElement.appendChild(doc.createTextNode(termText));
 }
 
 QString Glossary::append(const QStringList& sourceTerms, const QStringList& targetTerms)
@@ -486,17 +588,21 @@ QString Glossary::append(const QStringList& sourceTerms, const QStringList& targ
     setClean(false);
     QDomElement termEntry=m_doc.createElement("termEntry");
     m_doc.elementsByTagName("body").at(0).appendChild(termEntry);
-    QString id=generateNewId();
-    termEntry.setAttribute("id", id);
-    
+
+    //m_entries=m_doc.elementsByTagName("termEntry");
+
+    QString newId=generateNewId();
+    termEntry.setAttribute(::id, newId);
+
     foreach (QString sourceTerm, sourceTerms)
         appendTerm(termEntry, sourceTerm, Project::instance()->sourceLangCode());
     foreach (QString targetTerm, targetTerms)
         appendTerm(termEntry, targetTerm, Project::instance()->targetLangCode());
 
     hashTermEntry(termEntry);
+    m_idsForEntriesById=m_entriesById.keys();
 
-    return id;
+    return newId;
 }
 
 void Glossary::append(const QString& _english, const QString& _target)
@@ -509,6 +615,7 @@ void Glossary::clear()
     setClean(true);
     //path.clear();
     idsByLangWord.clear();
+    m_entriesById.clear();
 
     removedIds.clear();
     changedIds_.clear();
@@ -517,6 +624,8 @@ void Glossary::clear()
     termList_.clear();
     langWordEntry_.clear();
     subjectFields_=QStringList(QLatin1String(""));
+    
+    m_doc.clear();
 }
 
 
@@ -539,11 +648,17 @@ bool GlossaryModel::removeRows(int row, int count, const QModelIndex& parent)
 //         return false;
 QString GlossaryModel::appendRow(const QString& _english, const QString& _target)
 {
-    beginInsertRows(QModelIndex()/*parent*/,rowCount(),rowCount());
+    bool notify=!canFetchMore(QModelIndex());
+    if (notify)
+        beginInsertRows(QModelIndex(),rowCount(),rowCount());
 
-    QString id=Project::instance()->glossary()->append(QStringList(_english), QStringList(_target));
+    QString id=m_glossary->append(QStringList(_english), QStringList(_target));
 
-    endInsertRows();
+    if (notify)
+    {
+        m_visibleCount++;
+        endInsertRows();
+    }
     return id;
 }
 
