@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -35,6 +35,7 @@
 MergeCatalog::MergeCatalog(QObject* parent, Catalog* baseCatalog, bool saveChanges)
  : Catalog(parent)
  , m_baseCatalog(baseCatalog)
+ , m_modified(false)
 {
     setActivePhase(baseCatalog->activePhase(),baseCatalog->activePhaseRole());
     if (saveChanges)
@@ -59,10 +60,12 @@ void MergeCatalog::copyFromBaseCatalog(const DocPosition& pos, int options)
             //kWarning()<<ourPos.entry<<"SHIT";
             m_storage->setApproved(ourPos, m_baseCatalog->isApproved(pos));
         m_storage->setTarget(ourPos,m_baseCatalog->target(pos));
+        setModified(ourPos, true);
 
         if (options&EvenIfNotInDiffIndex && a)
             m_mergeDiffIndex.removeAll(pos.entry);
 
+        m_modified=true;
         emit signalEntryModified(pos);
     }
 }
@@ -111,22 +114,40 @@ MatchItem MergeCatalog::calcMatchItem(const DocPosition& basePos,const DocPositi
     CatalogStorage& baseStorage=*(m_baseCatalog->m_storage);
     CatalogStorage& mergeStorage=*(m_storage);
 
-    MatchItem item(mergePos.entry,0,true);
+    MatchItem item(mergePos.entry, basePos.entry, true);
     //TODO make more robust, perhaps after XLIFF?
     QStringList baseMatchData=baseStorage.matchData(basePos);
+    QStringList mergeMatchData=mergeStorage.matchData(mergePos);
 
                                             //compare ids
-    item.score+=20*(baseMatchData.isEmpty()?baseStorage.id(basePos)==mergeStorage.id(mergePos)
-                                           :baseMatchData==mergeStorage.matchData(mergePos));
+    item.score+=40*((baseMatchData.isEmpty()&&mergeMatchData.isEmpty())?baseStorage.id(basePos)==mergeStorage.id(mergePos)
+                                           :baseMatchData==mergeMatchData);
 
     //TODO look also for changed/new <note>s
 
     //translation isn't changed
-    if (baseStorage.targetAllForms(basePos)==mergeStorage.targetAllForms(mergePos))
+    if (baseStorage.targetAllForms(basePos, true)==mergeStorage.targetAllForms(mergePos, true))
     {
         item.translationIsDifferent=baseStorage.isApproved(basePos)!=mergeStorage.isApproved(mergePos);
         item.score+=29+1*item.translationIsDifferent;
     }
+#if 0
+    if (baseStorage.source(basePos)=="%1 (%2)")
+    {
+        qDebug()<<"BASE";
+        qDebug()<<m_baseCatalog->url();
+        qDebug()<<basePos.entry;
+        qDebug()<<baseStorage.source(basePos);
+        qDebug()<<baseMatchData.first();
+        qDebug()<<"MERGE";
+        qDebug()<<url();
+        qDebug()<<mergePos.entry;
+        qDebug()<<mergeStorage.source(mergePos);
+        qDebug()<<mergeStorage.matchData(mergePos).first();
+        qDebug()<<item.score;
+        qDebug()<<"";
+    }
+#endif
     return item;
 }
 
@@ -151,6 +172,7 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
     int size=baseStorage.size();
     int mergeSize=mergeStorage.size();
     m_map.fill(-1,size);
+    QMultiMap<int,int> backMap; //will be used to maintain one-to-one relation
 
 
     //precalc for fast lookup
@@ -165,7 +187,7 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
     while (i.entry<size)
     {
         QString key=strip(baseStorage.source(i));
-        QList<int> entries=mergeMap.values(key);
+        const QList<int>& entries=mergeMap.values(key);
         QList<MatchItem> scores;
         int k=entries.size();
         if (k)
@@ -176,30 +198,58 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
             qSort(scores.begin(), scores.end(), qGreater<MatchItem>());
 
             m_map[i.entry]=scores.first().mergeEntry;
+            backMap.insert(scores.first().mergeEntry, i.entry);
 
             if (scores.first().translationIsDifferent)
                 m_mergeDiffIndex.append(i.entry);
 
-            QMultiHash<QString, int>::iterator it = mergeMap.find(key);
-            while (it != mergeMap.end() && it.key() == key && it.value()!=scores.first().mergeEntry)
-                ++it;
-            mergeMap.erase(it);
         }
         ++i.entry;
     }
 
-    //fuzzy match unmatched entries
-    QMultiHash<QString, int>::iterator it = mergeMap.begin();
+
+    //maintain one-to-one relation
+    const QList<int>& mergePositions=backMap.uniqueKeys();
+    foreach(int mergePosition, mergePositions)
+    {
+        const QList<int>& basePositions=backMap.values(mergePosition);
+        if (basePositions.size()==1)
+            continue;
+
+        //qDebug()<<"kv"<<mergePosition<<basePositions;
+        QList<MatchItem> scores;
+        foreach(int value, basePositions)
+            scores<<calcMatchItem(DocPosition(value), mergePosition);
+
+        qSort(scores.begin(), scores.end(), qGreater<MatchItem>());
+        int i=scores.size();
+        while(--i>0)
+        {
+            //qDebug()<<"erasing"<<scores.at(i).baseEntry<<m_map[scores.at(i).baseEntry]<<",m_map["<<scores.at(i).baseEntry<<"]=-1";
+            m_map[scores.at(i).baseEntry]=-1;
+        }
+    }
+
+    //fuzzy match unmatched entries?
+/*    QMultiHash<QString, int>::iterator it = mergeMap.begin();
     while (it != mergeMap.end())
     {
         //kWarning()<<it.value()<<it.key();
         ++it;
-    }
-    m_unmatchedCount=mergeMap.count();
+    }*/
+    m_unmatchedCount=numberOfEntries()-mergePositions.count();
+    m_modified=false;
 
     return 0;
 }
 
+bool MergeCatalog::save()
+{
+    bool ok = !m_modified || Catalog::save();
+    if (ok) m_modified=false;
+    return ok;
+}
+
 void MergeCatalog::copyToBaseCatalog(DocPosition& pos)
 {
     bool changeContents=m_baseCatalog->msgstr(pos)!=msgstr(pos);
@@ -244,6 +294,8 @@ void MergeCatalog::copyToBaseCatalog(int options)
         pos.entry=entry;
         if (options&EmptyOnly&&!m_baseCatalog->isEmpty(entry))
             continue;
+        if (options&HigherOnly&&!m_baseCatalog->isEmpty(entry)&&m_baseCatalog->state(pos)>=state(pos))
+            continue;
 
         int formsCount=(m_baseCatalog->isPlural(entry))?m_baseCatalog->numberOfPluralForms():1;
         pos.form=0;
@@ -251,7 +303,8 @@ void MergeCatalog::copyToBaseCatalog(int options)
         {
             //m_baseCatalog->push(new DelTextCmd(m_baseCatalog,pos,m_baseCatalog->msgstr(pos.entry,0))); ?
             //some forms may still contain translation...
-            if (!(options&EmptyOnly) || m_baseCatalog->isEmpty(pos))
+            if (!(options&EmptyOnly && !m_baseCatalog->isEmpty(pos)) /*&& 
+                !(options&HigherOnly && !m_baseCatalog->isEmpty(pos) && m_baseCatalog->state(pos)>=state(pos))*/)
             {
                 if (!insHappened)
                 {
