@@ -60,6 +60,8 @@ public:
     void setLegacyUnitsCount(int to);
 
 signals:
+    void projectOpenRequested(QString path=QString());
+
     void fileOpenRequested(const KUrl&);
 
     void searchRequested(const KUrl::List&);
@@ -100,7 +102,7 @@ private slots:
 
 private:
     ProjectWidget* m_browser;
-    KLineEdit* m_lineEdit;
+    KLineEdit* m_filterEdit;
     QProgressBar* m_progressBar;
 
     int m_legacyUnitsCount, m_currentUnitsCount;
