@@ -35,16 +35,16 @@
 ;; as in qtopia/qpeapplication, then insert the following code in your setup
 ;; (setq kdab-prefix-qpe nil)
 ;;
-;; If you are using Qt 4 rather than Qt 3, insert the following line into you setup:
-;; (setq kdab-qt-version 4)
+;; If you are using Qt 3 rather than Qt 4, insert the following line into you setup:
+;; (setq kdab-qt-version 3)
 ;; or in a .emacs-dirvars file:
-;; kdab-qt-version: 4
+;; kdab-qt-version: 3
 ;;
 ;; Finally, if you do not want header files to be inserted lower-cased when
 ;; not found locally, insert (kdab-lowercase-header-files nil)
 
 ;; ------------------------------ CONFIGURATION ------------------------------
-(defvar kdab-qt-version 3
+(defvar kdab-qt-version 4
   "Specify which header files to use")
 
 (defvar kdab-include-qpe nil
@@ -56,6 +56,14 @@
 (defvar kdab-lowercase-header-files 't
   "Should header files be all lowercase, or would you prefer to use same case as class?")
 
+(defvar kdab-private-special-includes '()
+  "Override variable for special include specifications")
+
+(defvar kdab-suffix-for-private-headers "_p\\|_priv"
+  "Regular expression specifying the possible suffix to a file name for private includes.
+The default regular expression allows that a file named test.cpp may include test_p.h or test_priv.h.
+This is used when inserting headers, to ensure that no includes are inserted before the private header")
+
 ;; ------------------------------ Include Specifications ------------------------------ 
 ;; special case for include files
 ;; Please notify blackie@klaralvdalens-datakonsult.se with any modification to this variable!
@@ -112,12 +120,14 @@
 
     ; Useful fake entries
     (kapplication.h kapp)
-    (klocale.h i18n I18N_NOOP)
+    (klocale.h i18n i18nc i18ncp i18np I18N_NOOP)
     (kstandarddirs.h locate locateLocal)
     (stdlib.h getenv)
     (unistd.h unlink sleep usleep)
     (iostream cout cerr)
     (ctype.h isalnum isalpha isascii isblank iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit)
+    (string.h strcpy strlen memcpy strerror)
+    (stdlib.h atoi atol)
     )
     "List of special include files which do not follow the normal scheme")
 
@@ -257,128 +267,9 @@
     (tzselect.h TZCombo TimeZoneSelector)
     ))
 
+; List of classes in Qt4 that don't start with a Q.
 (defvar kdab-qt4-classes
-  '(QtNsPlugin QClipboard QPixmap QPen QRgb QMessageBox
-               QRegion QImageReader QItemEditorCreator QTimeEdit QCloseEvent QPushButton
-               QAbstractScrollArea QTabBar QSlider QPicture QRadialGradient QStandardItemModel QStringListModel
-               QListWidget QPageSetupDialog QAccessibleApplication QHelpEvent QTextDocumentFragment QDragMoveEvent
-               QImageIOHandlerFactoryInterface QDropEvent QInputContextFactoryInterface QStyleHintReturnMask QWidget QTextTableCell
-               QPrintDialog QKeyEvent QDial QDrag QFont QIcon
-               QItemSelection QMenu QImageWriter QAbstractSlider QtGui QStyleOptionToolBox
-               QTableView QWidgetData QPrintEngine QWidgetItem QWidgetList QStyleOptionProgressBar
-               QScrollBar QPolygon QAccessibleFactoryInterface QProgressDialog QStyleOptionButton QClipboardEvent
-               QHideEvent QDragLeaveEvent QWhatsThisClickedEvent QColor QLineEdit QStyleOptionFocusRect
-               QFrame QImage QPrinter QLabel QMovie QStyleOptionTabWidgetFrame
-               QSound QStyle QMoveEvent QAccessibleBridge QStyleOptionHeader QFileOpenEvent
-               QGradientStop QMenuItem QAbstractPageSetupDialog QVBoxLayout QItemEditorFactory QTextObjectInterface
-               QIconEngineFactoryInterface QTreeView QStyleOptionTabBarBase QWhatsThisAction QListView QGradientStops
-               QRegExpValidator QAbstractSpinBox QTextFragment QStackedLayout QAccessibleInterface QCommonStyle
-               QIconEngine QDateEdit QLayoutIterator QPictureFormatInterface QTextTableFormat QResizeEvent
-               QFontMetrics QGradient QImageIOHandler QShortcut QAccessibleObject QTextBlockGroup
-               QStyleOptionSlider QApplication QTableWidgetItem QInputDialog QPainterPathStroker QVBoxWidget
-               QAccessiblePlugin QTextBrowser QStyleFactoryInterface QImageTextKeyLang QErrorMessage QTextFrameLayoutData
-               QHoverEvent QX11Info QScrollArea QDirModel QAbstractTextDocumentLayout QWindowsStyle
-               QStackedWidget QStyleOptionTitleBar QAbstractItemView QStylePainter QSplitter QStyleOptionViewItem
-               QAccessibleWidget QVFbHeader QAccessible QTextFrameFormat QGridLayout QButtonGroup
-               QFontInfo QMotifPlusStyle QProgressBar QLinearGradient QMacMime QContextMenuEvent
-               QStyleHintReturn QStyleOptionQ3ListViewItem QActionEvent QActionGroup QDockWidget QWidgetContainerPlugin
-               QWSUpdateEvent QStyleOptionMenuItem QVFbKeyData QAbstractItemDelegate QPolygonF QCheckBox
-               QIntValidator QColorGroup QTreeWidgetItem QGroupBox QCursorShape QTableWidgetSelectionRange
-               QCompactStyle QSplitterHandle QMenuBar QStyleOptionDockWidget QWindowsXPStyle QPixmapCache
-               QSpinBox QDoubleSpinBox QTextCursor QFontMetricsF QInputMethodEvent QShortcutEvent
-               QSizeGrip QInputContextFactory QLCDNumber QTextEdit QTextItem QTextLine
-               QTextList QToolButton QGridWidget QFontDatabase QTextFormat QListWidgetItem
-               QPlatinumStyle QAccessibleBridgeFactoryInterface QKeySequence QStyleOptionComplex QTableWidget QFontDialog
-               QTextInlineObject QStyleOptionFrame QComboBox QTextListFormat QHBoxLayout QColormap
-               QDragEnterEvent QStyleOptionQ3ListView QDragResponseEvent QValidator QStyleOptionToolButton QItemDelegate
-               QStyleOptionQ3DockWindow QTextDocument QWMatrix QTextLayout QTreeWidget QRadioButton
-               QSplashScreen QToolBarChangeEvent QTextCharFormat QToolBar QToolBox QToolTip
-               QDesktopWidget QDoubleValidator QShowEvent QTextObject QConicalGradient QTextOption
-               QDateTimeEdit QWidgetMapper QWindowsMime QStyleOption QLayoutItem QTextBlock
-               QTextImageFormat QTextFrame QPaintDevice QSizePolicy QTextTable QFocusEvent
-               QAction QFocusFrame QTextBlockFormat QHBoxWidget QHeaderView QPaintEngine
-               QWidgetPlugin QMainWindow QBitmap QAbstractUndoItem QSpacerItem QFileIconProvider
-               QColorDialog QDialog QDialogButtonBox QCDEStyle QCursor QTabWidget QItemSelectionModel
-               QFileDialog QInputEvent QItemSelectionRange QProxyModel QRubberBand QItemEditorCreatorBase
-               QMotifStyle QPainterPathPrivate QStatusTipEvent QAbstractButton QPictureIO QWheelEvent
-               QAbstractPrintDialog QBrushData QInputContext QMouseEvent QBoxLayout QLayout
-               QPainter QPalette QMatrix QIconSet QWidgetFactoryInterface QStyleOptionComboBox
-               QSessionManager QStyleOptionSpinBox QTabletEvent QStyleOptionTab QStatusBar QWhatsThis
-               QPaintEvent QStyleFactory QSGIStyle QIconDragEvent QSqlRelationalDelegate QTDSResult
-               QOCIResult QtSql QPSQLResult QSqlDriver QSqlDriverFactoryInterface QSqlTableModel
-               QIBaseDriver QSqlRelation QSqlRecord QSqlResult QSqlDatabase QIBaseResult
-               QSQLiteDriver QSqlDriverCreatorBase QSQLite2Driver QSqlError QSqlField QSqlIndex
-               QSqlQuery QODBCDriver QSQLiteResult QDB2Driver QSQLite2Result QSqlRelationalTableModel
-               QMYSQLDriver QODBCResult QSqlDriverCreator QDB2Result QSqlQueryModel QTDSDriver
-               QOCIDriver QPSQLDriver QMYSQLResult QDomProcessingInstruction QXmlContentHandler QXmlParseException
-               QXmlLexicalHandler QtXml QDomNodeList QDomElement QDomDocument QDomDocumentType
-               QDomAttr QDomNode QDomText QDomEntity QDomNotation QXmlDefaultHandler
-               QDomDocumentFragment QXmlDeclHandler QXmlAttributes QXmlEntityResolver QDomImplementation QXmlInputSource
-               QXmlLocator QXmlReader QDomNamedNodeMap QXmlDTDHandler QXmlErrorHandler QDomCharacterData
-               QDomEntityReference QXmlNamespaceSupport QXmlSimpleReader QDomCDATASection QDomComment QTS
-               QDir QMap QSet QUrl QPointF QSharedDataPointer
-               QStringMatcher QVariantMap QRegExp QVectorData QIODevice QReadLocker
-               QVariantComparisonHelper QSignal QThread QString QLatin1String QVector
-               QSingleCleanupHandler QtPluginInstanceFunction QBool QChar QDate QFile
-               QFlag QLine QList QPair QRect QSize
-               QTime QUuid Q_PID QPointer QAbstractEventDispatcher QCharRef
-               QStringListIterator QAbstractListModel QChildEvent QMutableSetIterator QFactoryInterface QGlobalStatic
-               Q_INT16 Q_INT32 Q_INT64 Q_LLONG QCache QDebug
-               QEvent QFlags Q_UINT8 Q_ULONG QMutableStringListIterator QLineF
-               QMutex QProcess QPoint QSignalEmitter QRectF QQueue
-               QSizeF QStack QTimer QTextCodecFactoryInterface Q_INT8 Q_LONG
-               QCleanupHandler QBasicAtomicPointer QtCore QByteRef QBitArray QVariantList
-               QSharedCleanupHandler QListData QMetaEnum QMetaType QModelIndexList QSocketNotifier
-               QDateTime QDataStream QStringList QObjectData QObjectList QForeachContainer
-               QtAlgorithms QLibraryInfo QSharedData QResource QByteArrayMatcher QMutableVectorIterator
-               QTypeInfo QVectorTypedData QSemaphore QThreadStorage QMetaProperty QVectorIterator
-               QTranslatorMessage QPersistentModelIndex QMutexLocker QLibrary QSignalMapper QTextDecoder
-               QMetaClassInfo QSetIterator QtMsgHandler QMapData QHashIterator QFixedPoint
-               QMultiMap QFileEngineHandler QHashDummyValue QBasicTimer QCoreApplication QFileInfo
-               QExplicitlySharedDataPointer QTimerEvent QNoImplicitBoolCast QMutableHashIterator QMutableMapIterator QEventLoop
-               QCustomEvent QGenericReturnArgument QHashData QHashNode QSysInfo QFileInfoListIterator
-               QByteArray QModelIndex QWaitCondition QVarLengthArray QMetaMember QTextEncoder
-               QLatin1Char QMimeData QMetaObject QForeachMemory QThreadStorageData QMetaResource
-               QTemporaryFile QTextCodec QListIterator QLinkedListData QFileInfoList QLinkedListNode
-               QNoDebug QReadWriteLock QTextStream QObjectCleanupHandler QFixedPointLong QtCleanUpFunction
-               QAtomic QBitRef QTextStreamFunction QGenericArgument QObjectUserData QVariant
-               QBuffer QLinkedList QArgument QMetaTypeId QtGlobal QTextOStream
-               QMutableListIterator QFileEngine QWriteLocker QBasicAtomic QTextStreamManipulator QStdWString
-               QLinkedListIterator Q_UINT16 Q_UINT32 Q_UINT64 Q_ULLONG QAbstractTableModel
-               QMapIterator QAtomicPointer QLocale QMutableLinkedListIterator QConstString QAbstractItemModel
-               QSettings QObject QTextIStream QReturnArgument QTranslator QPluginLoader
-               ActiveQt QFtp QTcpServer QTcpSocket QHttp QAbstractSocket
-               QIPv6Address QUdpSocket QHttpHeader QtNetwork QHttpResponseHeader QHttpRequestHeader
-               QHostInfo Q_IPV6ADDR QUrlInfo QHostAddress QMotif QtMotif
-               QMotifDialog QXtWidget QMotifWidget Q3DragObject Q3TabDialog Q3CanvasItemList
-               Q3DeepCopy Q3StrIVec Q3StrList Q3IntBucket Q3DropSite Q3PtrListStdIterator
-               Q3AsciiDictIterator Q3CanvasPixmapArray Q3ListBoxItem Q3ListBoxText Q3DockWindow Q3Dns
-               Q3Ftp Q3Url Q3SqlPropertyMap Q3ToolBar Q3HttpRequestHeader Q3SqlRecordInfo
-               Q3StringBucket Q3ImageDrag Q3Http Q3FileIconProvider Q3DockAreaLayout Q3CanvasRectangle
-               Q3ServerSocket Q3TableSelection Q3CanvasItem Q3CanvasLine Q3CanvasText Q3CanvasView
-               Q3StoredDrag Q3TextEditOptimPrivate Q3MultiLineEdit Q3ValueList Q3NetworkProtocolFactory Q3NetworkProtocol
-               Q3DnsSocket Q3CString Q3UriDrag Q3Action Q3ListViewItemIterator Q3Canvas
-               Q3IntCacheIterator Q3ValueListConstIterator Q3Button Q3GCache Q3Painter Q3TimeEdit
-               Q3DataBrowser Q3StyleSheet Q3Header Q3StrIList Q3MainWindow Q3WhatsThis
-               Q3NetworkOperation Q3SqlFieldInfoList Q3CanvasPolygon Q3FileDialog Q3DockArea Q3Picture
-               Q3SqlSelectCursor Q3MemArray Q3PtrListIterator Q3ComboTableItem Q3SortedList Q3CanvasPolygonalItem
-               Q3SocketDevice Q3HButtonGroup Q3PtrDictIterator Q3VButtonGroup Q3PolygonScanner Q3IconViewItem
-               Q3AsciiCacheIterator Q3PtrBucket Q3PointArray Q3ObjectDictionary Q3Shared Q3Signal
-               Q3SqlFieldInfo Q3TableItem Q3CheckTableItem Q3Socket Q3StrVec Q3SqlCursor
-               Q3DateTimeEdit Q3CheckListItem Q3ListView Q3Accel Q3Process Q3Cache
-               Q3GDict Q3GList Q3CanvasPixmap Q3Frame Q3LNode Q3SpinWidget
-               Q3FilePreview Q3Wizard Q3Table Q3ValueVector Q3SyntaxHighlighter Q3DataView
-               Q3DictIterator Q3DateEdit Q3CanvasSpline Q3CanvasSprite Q3ColorDrag Q3SimpleRichText
-               Q3ValueListIterator Qt3Support Q3ValueStack Q3WidgetStack Q3NetworkProtocolDict Q3HttpResponseHeader
-               Q3TextBrowser Q3ListBoxPixmap Q3GridView Q3SqlEditorFactory Q3CacheIterator Q3AsciiBucket
-               Q3EditorFactory Q3CanvasEllipse Q3MimeSourceFactory Q3PopupMenu Q3PaintDeviceMetrics Q3DateTimeEditBase
-               Q3HttpHeader Q3DataTable Q3ButtonGroup Q3ProgressDialog Q3Semaphore Q3ProgressBar
-               Q3NetworkProtocolFactoryBase Q3IconDrag Q3IconView Q3GroupBox Q3ListViewItem Q3IntDictIterator
-               Q3ActionGroup Q3ListBox Q3GVector Q3IconDragItem Q3RangeControl Q3StyleSheetItem
-               Q3StrListIterator Q3TextEdit Q3TextDrag Q3LocalFs Q3TextView Q3Workspace
-               Q3GListStdIterator Q3SqlForm Q3UrlOperator Q3ScrollView QGLContext QGLFormat
-               QGLWidget QGLColormap QtOpenGL 
-               QDesignerFormEditorInterface QDesignerCustomWidgetInterface QDesignerContainerExtension) )
+  '(ActiveQt) )
 
 ;; ------------------------------ SOURCE CODE ------------------------------
 
@@ -413,10 +304,11 @@
     res))
 
 (defun kdab-get-special-include-list ()
-  (kdab-join-lists kdab-special-includes
-                   (kdab-join-lists (if (eq kdab-qt-version 3) kdab-qt3-special-includes 
-                                      (if (eq kdab-qt-version 4) (kdab-build-qt4-special-includes) '()))
-                                    (if kdab-include-qpe (kdab-build-qpe-special-incldues) '()))))
+  (kdab-join-lists kdab-private-special-includes
+                   (kdab-join-lists kdab-special-includes
+                                    (kdab-join-lists (if (eq kdab-qt-version 3) kdab-qt3-special-includes 
+                                                       (if (eq kdab-qt-version 4) (kdab-build-qt4-special-includes) '()))
+                                                     (if kdab-include-qpe (kdab-build-qpe-special-incldues) '())))))
 
 ;; Lookup class `cls' in kdab-special-includes and return the associate include file name
 (defun kdab-map-special (cls)
@@ -433,7 +325,10 @@
       (setq list (cdr list)))
     (if found
         (symbol-name found)
-      nil)  ; return value
+         ; not found: check if starts with 'Q'
+      (if (string-startsWith cls "Q")
+	  cls ; assume a Qt-4 forwarding header exists for the class
+	nil))  ; return value
     ))
         
 
@@ -465,11 +360,11 @@
                     ((and (string-match "^qdom" word) (eq kdab-qt-version 3)) "qdom.h")
                     ((and (string-match "^qxml" word) (eq kdab-qt-version 3)) "qxml.h")
                     ((and (string-match "^q" word) (eq kdab-qt-version 3)) (concat word ".h") )
+                    ((and (string-match "^q" word) (eq kdab-qt-version 4)) word-with-case )
                     (kdab-lowercase-header-files (concat word ".h" ))
                     (t (concat word-with-case ".h"))))
            header is-local override)
 
-      
       ;; decide on the header file.
       (if (functionp 'kdab-name-include-file)
           (setq override (kdab-name-include-file word-with-case)))
@@ -518,24 +413,42 @@
             (message (concat "commented in #include for " header))))
       
       (if (not (re-search-forward (concat "#include *[\"<][ \t]*" header "[ \t]*[\">]") nil t))
-          (progn
-            ; No include existed
-            (goto-char (point-max)) ; Using end-of-buffer makes point move, despite save-excursion
-	    (while (and (re-search-backward "^#include *[\"<]\\([^\">]+\\)[\">]" nil t)
-			(string-match ".*moc.*" (match-string 1))) 
-	      ; each iteration moves up until finding a #include which isn't a moc
-	      )
-            (if (not (looking-at "^#include *[\"<][^\">]+ *[\">]"))
-                (beginning-of-buffer)
-              (progn (end-of-line) (forward-char 1)))
-            
-            ;; Now insert the header
-            (insert (concat include-file "\n"))
-            (when show-message
-              (message (concat "inserted " include-file))))
+          (kdab-insert-header-from-end include-file show-message) ;; No include existed
         (when show-message
-              (message (concat "header file \"" header "\" is already included")))))))
+          (message (concat "header file \"" header "\" is already included")))))))
 
+;--------------------------------------------------------------------------------
+; Insert header file starting the search from behind. This is a helper function for 
+; kdab-insert-include-file
+; Historically kdab-insert-include-file added the include file at the end of the list
+; of include files, which had the unfortunate effect that it sometimes inserted the
+; include into #ifdef'ed sections.
+; So now we insert it at the top of the list. We need to go after the include for
+; the source files own header.
+;--------------------------------------------------------------------------------
+(defun kdab-insert-header-from-end (include-file show-message)
+  (let ((basename (file-name-nondirectory (file-name-sans-extension (buffer-file-name))))
+        found-own-include found-any-include)
+    (goto-char (point-max)) ; Using end-of-buffer makes point move, despite save-excursion
+    (setq found-own-include 
+          (re-search-backward (concat "^[ \t]*#[ \t]*include[ \t]*[\"<]" basename "\\(" 
+                                      kdab-suffix-for-private-headers "\\)?\\(.h\\)?[\">]") nil 't))
+    
+    (if found-own-include
+        (progn ; Found an include for my own header file
+          (next-line 1)
+          (beginning-of-line))
+      (progn ; Did not find a local include - we will then insert before first include
+        (beginning-of-buffer)
+        (setq found-any-include (re-search-forward "^[ \s]*#include[ \t]*[\"<]\\([^\">]+\\)[\">]" nil t))
+        (if found-any-include
+            (beginning-of-line) ;; OK we found some include
+          (beginning-of-buffer)))) ;; None found at all.
+
+    ;; Now insert the header
+    (insert (concat include-file "\n"))
+    (when show-message
+      (message (concat "inserted " include-file)))))
 
 
 ;----------------------------------------------------------------------------
