@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -72,12 +72,12 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
     UMLDragData *data = 0;
     QPixmap* png = 0;
 
-    UMLListView * listView = UMLApp::app()->getListView();
+    UMLListView * listView = UMLApp::app()->listView();
     UMLListViewItemList selectedItems;
 
     if(fromView) {
         m_type = clip4;
-        UMLView *view = UMLApp::app()->getCurrentView();
+        UMLView *view = UMLApp::app()->currentView();
         view->checkSelections();
         if(!view->getSelectedWidgets(m_WidgetList)) {
             return 0;
@@ -136,7 +136,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
         break;
     case clip4:
         if(png) {
-            UMLView *view = UMLApp::app()->getCurrentView();
+            UMLView *view = UMLApp::app()->currentView();
             data = new UMLDragData(m_ObjectList, m_WidgetList,
                                m_AssociationList, *png, view->getType());
         } else {
@@ -161,7 +161,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
  */
 bool UMLClipboard::paste(const QMimeData* data)
 {
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
     bool result = false;
     doc->beginPaste();
     switch(UMLDragData::getCodingType(data)) {
@@ -285,7 +285,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* item, bool & withDiagra
     if(!item) {
         return;
     }
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
     onlyAttsOps = true;
     UMLView * view = 0;
     UMLListViewItem * child = 0;
@@ -351,8 +351,8 @@ bool UMLClipboard::pasteChildren(UMLListViewItem *parent, IDChangeLog *chgLog)
         uWarning() << "Paste Children Error, parent missing";
         return false;
     }
-    UMLDoc *doc = UMLApp::app()->getDocument();
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLDoc *doc = UMLApp::app()->document();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem *childItem = static_cast<UMLListViewItem*>(parent->firstChild());
     while (childItem) {
         Uml::IDType oldID = childItem->getID();
@@ -369,7 +369,7 @@ bool UMLClipboard::pasteChildren(UMLListViewItem *parent, IDChangeLog *chgLog)
             uDebug() << "adjusting lvitem(" << ID2STR(oldID)
                 << ") to new UMLObject(" << ID2STR(newID) << ")";
             childItem->setUMLObject(newObj);
-            childItem->setText(newObj->getName());
+            childItem->setText(newObj->name());
         } else {
             uDebug() << "no UMLObject found for lvitem " << ID2STR(newID);
         }
@@ -404,7 +404,7 @@ bool UMLClipboard::pasteClip1(const QMimeData* data)
     if (! UMLDragData::decodeClip1(data, objects)) {
         return false;
     }
-    UMLListView *lv = UMLApp::app()->getListView();
+    UMLListView *lv = UMLApp::app()->listView();
     if ( !lv->startedCopy() )
         return true;
     lv->setStartedCopy(false);
@@ -432,7 +432,7 @@ bool UMLClipboard::pasteClip1(const QMimeData* data)
  */
 bool UMLClipboard::pasteClip2(const QMimeData* data)
 {
-    UMLDoc*             doc = UMLApp::app()->getDocument();
+    UMLDoc*             doc = UMLApp::app()->document();
     UMLListViewItemList itemdatalist;
     UMLObjectList       objects;
     UMLViewList         views;
@@ -443,7 +443,7 @@ bool UMLClipboard::pasteClip2(const QMimeData* data)
         return false;
     }
 
-    idchanges = doc->getChangeLog();
+    idchanges = doc->changeLog();
     if(!idchanges) {
         return false;
     }
@@ -460,7 +460,7 @@ bool UMLClipboard::pasteClip2(const QMimeData* data)
         }
     }
 
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
 
     foreach ( UMLListViewItem* itemdata, itemdatalist ) {
         UMLListViewItem* item = listView->createItem(*itemdata, *idchanges);
@@ -485,15 +485,15 @@ bool UMLClipboard::pasteClip2(const QMimeData* data)
  */
 bool UMLClipboard::pasteClip3(const QMimeData* data)
 {
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
     UMLListViewItemList itemdatalist;
-    IDChangeLog* idchanges = doc->getChangeLog();
+    IDChangeLog* idchanges = doc->changeLog();
 
     if(!idchanges) {
         return false;
     }
 
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     bool result = UMLDragData::decodeClip3(data, itemdatalist, listView);
     if(!result) {
         return false;
@@ -519,7 +519,7 @@ bool UMLClipboard::pasteClip3(const QMimeData* data)
  */
 bool UMLClipboard::pasteClip4(const QMimeData* data)
 {
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
 
     UMLObjectList objects;
     UMLWidgetList widgets;
@@ -533,7 +533,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
         return false;
     }
 
-    if( diagramType != UMLApp::app()->getCurrentView()->getType() ) {
+    if( diagramType != UMLApp::app()->currentView()->getType() ) {
         if( !checkPasteWidgets(widgets) ) {
             while ( !assocs.isEmpty() ) {
                 delete assocs.takeFirst();
@@ -542,7 +542,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
         }
     }
 
-    idchanges = doc->getChangeLog();
+    idchanges = doc->changeLog();
     if(!idchanges) {
         return false;
     }
@@ -557,7 +557,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
 
     //now add any widget we are want to paste
     bool objectAlreadyExists = false;
-    UMLView *currentView = UMLApp::app()->getCurrentView();
+    UMLView *currentView = UMLApp::app()->currentView();
     currentView->beginPartialWidgetPaste();
 
     foreach ( UMLWidget* widget, widgets ) {
@@ -589,7 +589,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
     currentView->endPartialWidgetPaste();
 
     /*
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem* item = 0;
     UMLListViewItem* itemdata = 0;
     UMLListViewItemListIt it(itemdatalist);
@@ -620,8 +620,8 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
  */
 bool UMLClipboard::pasteClip5(const QMimeData* data)
 {
-    UMLDoc *doc = UMLApp::app()->getDocument();
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLDoc *doc = UMLApp::app()->document();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem* lvitem = dynamic_cast<UMLListViewItem *>( listView->currentItem() );
     if (!lvitem || !Model_Utils::typeIsClassifier( lvitem->getType() )) {
         return false;
@@ -643,59 +643,59 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
     }
 
     doc->setModified(true);
-    idchanges = doc->getChangeLog();
+    idchanges = doc->changeLog();
     // Assume success if at least one child object could be pasted
     if (objects.count())
         result = false;
 
     foreach (UMLObject* obj, objects ) {
-        obj->setID(doc->assignNewID(obj->getID()));
-        switch(obj->getBaseType()) {
+        obj->setID(doc->assignNewID(obj->id()));
+        switch(obj->baseType()) {
         case Uml::ot_Attribute :
             {
-                UMLObject *exist = parent->findChildObject(obj->getName(), Uml::ot_Attribute);
+                UMLObject *exist = parent->findChildObject(obj->name(), Uml::ot_Attribute);
                 if (exist) {
-                    QString newName = parent->uniqChildName(Uml::ot_Attribute, obj->getName());
+                    QString newName = parent->uniqChildName(Uml::ot_Attribute, obj->name());
                     obj->setName(newName);
                 }
                 UMLAttribute *att = static_cast<UMLAttribute*>(obj);
                 if (parent->addAttribute(att, idchanges)) {
                     result = true;
                 } else {
-                    uError() << "" << parent->getName() << "->addAttribute("
-                             << att->getName() << ") failed";
+                    uError() << "" << parent->name() << "->addAttribute("
+                             << att->name() << ") failed";
                 }
                 break;
             }
         case Uml::ot_Operation :
             {
                 UMLOperation *op = static_cast<UMLOperation*>(obj);
-                UMLOperation *exist = parent->checkOperationSignature(op->getName(), op->getParmList());
+                UMLOperation *exist = parent->checkOperationSignature(op->name(), op->getParmList());
                 if (exist) {
-                    QString newName = parent->uniqChildName(Uml::ot_Operation, obj->getName());
+                    QString newName = parent->uniqChildName(Uml::ot_Operation, obj->name());
                     op->setName(newName);
                 }
                 if (parent->addOperation(op, idchanges)) {
                     result = true;
                 } else {
-                    uError() << "" << parent->getName() << "->addOperation("
-                             << op->getName() << ") failed";
+                    uError() << "" << parent->name() << "->addOperation("
+                             << op->name() << ") failed";
                 }
                 break;
             }
         case Uml::ot_Template:
             {
                 UMLTemplate* tp = static_cast<UMLTemplate*>( obj );
-                UMLTemplate* exist = parent->findTemplate( tp->getName() );
+                UMLTemplate* exist = parent->findTemplate( tp->name() );
                 if ( exist ) {
-                    QString newName = parent->uniqChildName( Uml::ot_Template, obj->getName() );
+                    QString newName = parent->uniqChildName( Uml::ot_Template, obj->name() );
                     tp->setName( newName );
                 }
                 if ( parent->addTemplate( tp, idchanges ) ) {
                     result = true;
                 } else {
-                    uError() << "" << parent->getName() << "->addTemplate("
-                             << tp->getName() << ") failed";
+                    uError() << "" << parent->name() << "->addTemplate("
+                             << tp->name() << ") failed";
                 }
                 break;
             }
@@ -709,9 +709,9 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                    break;
                }
 
-               UMLObject* exist = enumParent->findChildObject( obj->getName(), Uml::ot_EnumLiteral );
+               UMLObject* exist = enumParent->findChildObject( obj->name(), Uml::ot_EnumLiteral );
                if ( exist ) {
-                   QString newName = enumParent->uniqChildName( Uml::ot_EnumLiteral, obj->getName() );
+                   QString newName = enumParent->uniqChildName( Uml::ot_EnumLiteral, obj->name() );
                    obj->setName( newName );
                }
                UMLEnumLiteral* enl = static_cast<UMLEnumLiteral*>( obj );
@@ -719,8 +719,8 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                if ( enumParent->addEnumLiteral( enl, idchanges ) ) {
                    result = true;
                } else {
-                   uError() << "" << enumParent->getName() << "->addEnumLiteral("
-                            << enl->getName() << ") failed";
+                   uError() << "" << enumParent->name() << "->addEnumLiteral("
+                            << enl->name() << ") failed";
                }
                break;
            }
@@ -733,9 +733,9 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                     uError() << "Parent is not an UMLEntity";
                     break;
                 }
-                UMLObject *exist = entityParent->findChildObject(obj->getName(), Uml::ot_EntityAttribute);
+                UMLObject *exist = entityParent->findChildObject(obj->name(), Uml::ot_EntityAttribute);
                 if (exist) {
-                    QString newName = entityParent->uniqChildName(Uml::ot_EntityAttribute, obj->getName());
+                    QString newName = entityParent->uniqChildName(Uml::ot_EntityAttribute, obj->name());
                     obj->setName(newName);
                 }
                 UMLEntityAttribute *att = static_cast<UMLEntityAttribute*>(obj);
@@ -743,7 +743,7 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                 if ( entityParent->addEntityAttribute(att, idchanges)) {
                     result = true;
                 } else {
-                    uError() << "" << parent->getName() << "->addEntityAttribute(" << att->getName() << ") failed";
+                    uError() << "" << parent->name() << "->addEntityAttribute(" << att->name() << ") failed";
                 }
                 break;
             }
@@ -822,7 +822,7 @@ bool UMLClipboard::checkPasteWidgets( UMLWidgetList & widgetList )
  */
 void UMLClipboard::pasteItemAlreadyExists()
 {
-    UMLView *currentView = UMLApp::app()->getCurrentView();
+    UMLView *currentView = UMLApp::app()->currentView();
     KMessageBox::sorry( currentView,
                         i18n("At least one of the items in the clipboard "
                              "could not be pasted because an item of the "
