@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -267,7 +267,7 @@ void UMLDragData::setUMLDataClip5(UMLObjectList& objects)
  */
 bool UMLDragData::decodeClip1(const QMimeData* mimeData, UMLObjectList& objects)
 {
-    UMLDoc* doc = UMLApp::app()->getDocument();
+    UMLDoc* doc = UMLApp::app()->document();
     if ( !mimeData->hasFormat("application/x-uml-clip1") ) {
         return false;
     }
@@ -294,7 +294,7 @@ bool UMLDragData::decodeClip1(const QMimeData* mimeData, UMLObjectList& objects)
         return false;
     }
 
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
 
     //UMLObjects
     QDomNode objectsNode = xmiClipNode.firstChild();
@@ -336,9 +336,9 @@ bool UMLDragData::decodeClip1(const QMimeData* mimeData, UMLObjectList& objects)
             if(!doc->assignNewIDs(pObject)) {
                 return false;
             }
-            Uml::Object_Type type = pObject->getBaseType();
-            QString newName = Model_Utils::uniqObjectName(type, pObject->getUMLPackage(),
-                                                                pObject->getName());
+            Uml::Object_Type type = pObject->baseType();
+            QString newName = Model_Utils::uniqObjectName(type, pObject->umlPackage(),
+                                                                pObject->name());
             pObject->setName(newName);
             /****************************************************************/
         }
@@ -423,7 +423,7 @@ bool UMLDragData::decodeClip2(const QMimeData* mimeData, UMLObjectList& objects,
         uWarning() << "No diagrams in XMI clip.";
         return false;
     }
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     while ( !diagramElement.isNull() ) {
         QString type = diagramElement.attribute("type", "0");
         Uml::Diagram_Type dt = (Uml::Diagram_Type)type.toInt();
@@ -431,7 +431,7 @@ bool UMLDragData::decodeClip2(const QMimeData* mimeData, UMLObjectList& objects,
         if (parent == NULL)
             return false;
         UMLObject *po = parent->getUMLObject();
-        if (po == NULL || po->getBaseType() != Uml::ot_Folder) {
+        if (po == NULL || po->baseType() != Uml::ot_Folder) {
             uError() << "Bad parent for view.";
             return false;
         }
@@ -673,7 +673,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
         return false;
     }
 
-    UMLView *view = UMLApp::app()->getCurrentView();
+    UMLView *view = UMLApp::app()->currentView();
     while ( !widgetElement.isNull() ) {
 
         UMLWidget* widget = view->loadWidgetFromXMI(widgetElement);
