@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,7 +31,7 @@ namespace Uml
 
     void CmdCreateActivityDiag::redo()
     {
-        UMLFolder* temp = m_pUMLDoc->getRootFolder(Uml::mt_Logical);
+        UMLFolder* temp = m_pUMLDoc->rootFolder(Uml::mt_Logical);
         m_pUMLView = m_pUMLDoc->createDiagram(temp, Uml::dt_Activity);
     }
 
