@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -22,7 +22,7 @@ namespace Uml
     CmdSetName::CmdSetName(UMLObject * obj, const QString& name)
       : m_umlObject(obj), m_name (name)
     {
-        m_oldname = obj->getName();
+        m_oldname = obj->name();
     }
 
     CmdSetName::~CmdSetName()
@@ -31,12 +31,12 @@ namespace Uml
 
     void CmdSetName::redo()
     {
-        m_umlObject->setNamecmd(m_name);
+        m_umlObject->setNameCmd(m_name);
     }
 
     void CmdSetName::undo()
     {
-        m_umlObject->setNamecmd(m_oldname);
+        m_umlObject->setNameCmd(m_oldname);
     }
 
 }
