@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2008                                               *
+ *   copyright (C) 2004-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@
 CPPCodeGenerationPolicyPage::CPPCodeGenerationPolicyPage( QWidget *parent, const char *name, CPPCodeGenerationPolicy * policy )
   : CodeGenerationPolicyPage(parent, name, policy)
 {
-    CodeGenerationPolicy *common = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *common = UMLApp::app()->commonPolicy();
 
     QVBoxLayout* vboxLayout = new QVBoxLayout( this );
 
@@ -60,7 +60,7 @@ CPPCodeGenerationPolicyPage::~CPPCodeGenerationPolicyPage()
 
 void CPPCodeGenerationPolicyPage::apply()
 {
-    CodeGenerationPolicy *common = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *common = UMLApp::app()->commonPolicy();
 
     // now do our cpp-specific configs
     CPPCodeGenerationPolicy * parent = (CPPCodeGenerationPolicy*) m_parentPolicy;
