@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -21,8 +21,6 @@
 #include "umlview.h"
 #include "stereotype.h"
 #include "umlpackagelist.h"
-#include "umllistviewitem.h"
-#include "umllistview.h"
 #include "model_utils.h"
 #include "package.h"
 #include "folder.h"
@@ -56,7 +54,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
 
     // setup name
     QString name;
-    Uml::Object_Type t = o->getBaseType();
+    Uml::Object_Type t = o->baseType();
     switch (t) {
     case Uml::ot_Class:
         name = i18n("Class &name:");
@@ -118,7 +116,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), o->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), o->stereotype() );
     m_pStereoTypeL->setBuddy(m_pStereoTypeCB);
 
     if (t == Uml::ot_Interface || t == Uml::ot_Datatype || t == Uml::ot_Enum) {
@@ -133,21 +131,21 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
         m_pPackageCB->setEditable(true);
         m_pNameLayout->addWidget(m_pPackageCB, 2, 1);
 
-        UMLPackageList packageList = m_pUmldoc->getPackages();
+        UMLPackageList packageList = m_pUmldoc->packages();
         QStringList packages;
         foreach( UMLPackage* package, packageList ) {
-            packages << package->getName();
+            packages << package->name();
         }
         packages.sort();
         m_pPackageCB->insertItems(-1, packages);
-        UMLPackage* parentPackage = o->getUMLPackage();
+        UMLPackage* parentPackage = o->umlPackage();
 
         // if parent package == NULL
         // or if the parent package is the Logical View folder
-        if ( parentPackage == NULL || parentPackage== static_cast<UMLPackage*>(m_pUmldoc->getRootFolder(Uml::mt_Logical)))
+        if ( parentPackage == NULL || parentPackage== static_cast<UMLPackage*>(m_pUmldoc->rootFolder(Uml::mt_Logical)))
             m_pPackageCB->setEditText( QString() );
         else
-            m_pPackageCB->setEditText(parentPackage->getName());
+            m_pPackageCB->setEditText(parentPackage->name());
     }
 
     if (t == Uml::ot_Class || t == Uml::ot_UseCase ) {
@@ -158,7 +156,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
             abstractCaption = i18n("A&bstract use case");
         }
         m_pAbstractCB = new QCheckBox( abstractCaption, this );
-        m_pAbstractCB->setChecked( o->getAbstract() );
+        m_pAbstractCB->setChecked( o->isAbstract() );
         m_pNameLayout->addWidget( m_pAbstractCB, 3, 0 );
     }
 
@@ -231,9 +229,9 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     topLayout->addWidget(m_pDocGB);
 
     // setup fields
-    m_pClassNameLE->setText(o->getName());
-    m_pDoc->setText(o->getDoc());
-    Uml::Visibility s = o->getVisibility();
+    m_pClassNameLE->setText(o->name());
+    m_pDoc->setText(o->doc());
+    Uml::Visibility s = o->visibility();
     if (s == Uml::Visibility::Public)
         m_pPublicRB->setChecked(true);
     else if (s == Uml::Visibility::Private)
@@ -246,7 +244,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     // manage stereotypes
     m_pStereoTypeCB->setDuplicatesEnabled(false);  // only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    insertStereotypesSorted(m_pObject->getStereotype());
+    insertStereotypesSorted(m_pObject->stereotype());
 
     m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
 }
@@ -282,7 +280,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pInstanceLE = new KLineEdit(this);
     m_pInstanceLE->setText(o->instanceName());
     m_pNameLayout->addWidget(m_pInstanceLE, 1, 1);
-    UMLView *view = UMLApp::app()->getCurrentView();
+    UMLView *view = UMLApp::app()->currentView();
 
     m_pDrawActorCB = new QCheckBox( i18n( "Draw as actor" ) , this );
     m_pDrawActorCB->setChecked( o->drawAsActor() );
@@ -351,7 +349,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->umlObject()->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->umlObject()->stereotype() );
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
 
     m_pInstanceL = new QLabel(this);
@@ -383,8 +381,8 @@ void ClassGenPage::insertStereotypesSorted(const QString& type)
 {
     QStringList types;
     types << "";  // an empty stereotype is the default
-    foreach (UMLStereotype* ust, m_pUmldoc->getStereotypes()) {
-        types << ust->getName();
+    foreach (UMLStereotype* ust, m_pUmldoc->stereotypes()) {
+        types << ust->name();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -418,7 +416,7 @@ void ClassGenPage::updateObject()
             m_pObject->setStereotype(m_pStereoTypeCB->currentText());
         }
 
-        Uml::Object_Type t = m_pObject->getBaseType();
+        Uml::Object_Type t = m_pObject->baseType();
         if (t == Uml::ot_Class || t == Uml::ot_Interface) {
             QString packageName = m_pPackageCB->currentText().trimmed();
             UMLObject* newPackage = NULL;
@@ -428,15 +426,11 @@ void ClassGenPage::updateObject()
                     newPackage = Import_Utils::createUMLObject(Uml::ot_Package, packageName);
                 }
             } else {
-                newPackage = m_pUmldoc->getRootFolder( Uml::mt_Logical );
+                newPackage = m_pUmldoc->rootFolder( Uml::mt_Logical );
             }
 
             // adjust list view items
-            UMLListView *lv = UMLApp::app()->getListView();
-            UMLListViewItem *newLVParent = lv->findUMLObject(newPackage);
-            lv->moveObject(m_pObject->getID(),
-                           Model_Utils::convert_OT_LVT(m_pObject),
-                           newLVParent);
+            Model_Utils::treeViewMoveObjectTo(newPackage, m_pObject);
         }
 
         if ( m_pAbstractCB ) {
@@ -448,7 +442,7 @@ void ClassGenPage::updateObject()
         if (o && m_pObject != o) {
              KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                 i18n("Name is Not Unique"), false);
-             m_pClassNameLE->setText( m_pObject->getName() );
+             m_pClassNameLE->setText( m_pObject->name() );
         } else {
              m_pObject->setName(name);
         }
@@ -464,11 +458,11 @@ void ClassGenPage::updateObject()
             s = Uml::Visibility::Implementation;
         m_pObject->setVisibility(s);
 
-        if (m_pObject->getBaseType() == Uml::ot_Component) {
+        if (m_pObject->baseType() == Uml::ot_Component) {
             (static_cast<UMLComponent*>(m_pObject))->setExecutable( m_pExecutableCB->isChecked() );
         }
 
-        if (m_pObject->getBaseType() == Uml::ot_Artifact) {
+        if (m_pObject->baseType() == Uml::ot_Artifact) {
             UMLArtifact::Draw_Type drawAsType;
             if ( m_pFileRB->isChecked() ) {
                 drawAsType = UMLArtifact::file;
@@ -480,6 +474,7 @@ void ClassGenPage::updateObject()
                 drawAsType = UMLArtifact::defaultDraw;
             }
             (static_cast<UMLArtifact*>(m_pObject))->setDrawAsType(drawAsType);
+            m_pObject->emitModified();
         }
     } // end if m_pObject
     else if (m_pWidget) {
