@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -39,7 +39,7 @@ UMLViewDialog::UMLViewDialog( QWidget * pParent, UMLView * pView )
     setFaceType( KPageDialog::List );
     showButtonSeparator( true );
     m_pView = pView;
-    m_options = m_pView -> getOptionState();
+    m_options = m_pView->getOptionState();
     setupPages();
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
@@ -106,7 +106,7 @@ void UMLViewDialog::setupDiagramPropertiesPage()
  */
 void UMLViewDialog::setupClassPage()
 {
-    if ( m_pView -> getType() != Uml::dt_Class ) {
+    if ( m_pView->getType() != Uml::dt_Class ) {
         return;
     }
     QFrame * newPage = new QFrame();
@@ -204,8 +204,8 @@ void UMLViewDialog::applyPage( KPageWidgetItem *item )
 void UMLViewDialog::checkName()
 {
     QString name = m_diagramProperties->ui_diagramName-> text();
-    UMLDoc * pDoc = UMLApp::app()-> getDocument();
-    UMLView * pView = pDoc -> findView( m_pView -> getType(), name );
+    UMLDoc * pDoc = UMLApp::app()->document();
+    UMLView * pView = pDoc->findView( m_pView->getType(), name );
     if ( name.length() == 0 ) {
         KMessageBox::sorry(this, i18n("The name you have entered is invalid."),
                            i18n("Invalid Name"), false);
