@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2006      Gael de Chalendar (aka Kleag) kleag@free.fr   *
- *   copyright (C) 2006-2007                                               *
+ *   copyright (C) 2006-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -35,7 +35,7 @@
  */
 DocbookGenerator::DocbookGenerator()
 {
-  umlDoc = UMLApp::app()->getDocument();
+  umlDoc = UMLApp::app()->document();
   m_pStatus = true;
   m_pThreadFinished = false;
   docbookGeneratorJob = 0;
